import React, { FC } from 'react';
import { Section } from '../../molecules/Section';
import CardGridCard, { CardProps } from './Card';
import Image from 'next/image';
import styles from "./CardGrid.module.scss";

interface GridColumns {
    mobile: number,
    tablet: number,
    desktop: number,
}

interface CardGridProps {
    gridColumns: GridColumns,
    cardList?: Maybe<CardProps[]>,
    backgroundImage: string
}

export const CardGrid: FC<CardGridProps> = ({ gridColumns, cardList, backgroundImage }) => {
    return (
        <Section noPadding="noPaddingY" className="container">
            <Image
                src={backgroundImage}
                alt=""
                className={styles["card-grid__img"]}
                fill
                ></Image>
            <div className={`tw-py-10 lg:tw-pb-20 tw-w-full tw-grid tw-grid-cols-${gridColumns.mobile} md:tw-grid-cols-${gridColumns.tablet} lg:tw-grid-cols-${gridColumns.desktop} tw-gap-5`}>
                {cardList && cardList.map((card, index) => (
                    <CardGridCard key={index} heading={card.heading} content={card.content} buttons={card.buttons} />
                ))}
            </div>
        </Section>
    );
};
